==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/foundation/NSMethodSignature.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.foundation;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.corefoundation.*;
import org.robovm.apple.uikit.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coremedia.*;
import org.robovm.apple.security.*;
import org.robovm.apple.dispatch.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*/@Library("Foundation") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/NSMethodSignature/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class NSMethodSignaturePtr extends Ptr<NSMethodSignature, NSMethodSignaturePtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(NSMethodSignature.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public NSMethodSignature() {}
    protected NSMethodSignature(SkipInit skipInit) { super(skipInit); }
    public NSMethodSignature(@org.robovm.rt.bro.annotation.Marshaler(StringMarshalers.AsDefaultCharsetZMarshaler.class) String types) { super(create(types)); retain(getHandle()); }
    /*</constructors>*/
    /*<properties>*/
    @Property(selector = "numberOfArguments")
    public native @MachineSizedUInt long getNumberOfArguments();
    @Property(selector = "frameLength")
    public native @MachineSizedUInt long getFrameLength();
    @Property(selector = "methodReturnType")
    public native @org.robovm.rt.bro.annotation.Marshaler(StringMarshalers.AsDefaultCharsetZMarshaler.class) String getMethodReturnType();
    @Property(selector = "methodReturnLength")
    public native @MachineSizedUInt long getMethodReturnLength();
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "getArgumentTypeAtIndex:")
    public native @org.robovm.rt.bro.annotation.Marshaler(StringMarshalers.AsDefaultCharsetZMarshaler.class) String getArgumentType(@MachineSizedUInt long idx);
    @Method(selector = "isOneway")
    public native boolean isOneway();
    @Method(selector = "signatureWithObjCTypes:")
    protected static native @Pointer long create(@org.robovm.rt.bro.annotation.Marshaler(StringMarshalers.AsDefaultCharsetZMarshaler.class) String types);
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.16-sources.jar: org/robovm/apple/foundation/NSMethodSignature.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.foundation;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.corefoundation.*;
import org.robovm.apple.uikit.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coremedia.*;
import org.robovm.apple.security.*;
import org.robovm.apple.dispatch.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*/@Library("Foundation") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/NSMethodSignature/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class NSMethodSignaturePtr extends Ptr<NSMethodSignature, NSMethodSignaturePtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(NSMethodSignature.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public NSMethodSignature() {}
    protected NSMethodSignature(Handle h, long handle) { super(h, handle); }
    protected NSMethodSignature(SkipInit skipInit) { super(skipInit); }
    public NSMethodSignature(@org.robovm.rt.bro.annotation.Marshaler(StringMarshalers.AsDefaultCharsetZMarshaler.class) String types) { super((Handle) null, create(types)); retain(getHandle()); }
    /*</constructors>*/
    /*<properties>*/
    @Property(selector = "numberOfArguments")
    public native @MachineSizedUInt long getNumberOfArguments();
    @Property(selector = "frameLength")
    public native @MachineSizedUInt long getFrameLength();
    @Property(selector = "methodReturnType")
    public native @org.robovm.rt.bro.annotation.Marshaler(StringMarshalers.AsDefaultCharsetZMarshaler.class) String getMethodReturnType();
    @Property(selector = "methodReturnLength")
    public native @MachineSizedUInt long getMethodReturnLength();
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "getArgumentTypeAtIndex:")
    public native @org.robovm.rt.bro.annotation.Marshaler(StringMarshalers.AsDefaultCharsetZMarshaler.class) String getArgumentType(@MachineSizedUInt long idx);
    @Method(selector = "isOneway")
    public native boolean isOneway();
    @Method(selector = "signatureWithObjCTypes:")
    protected static native @Pointer long create(@org.robovm.rt.bro.annotation.Marshaler(StringMarshalers.AsDefaultCharsetZMarshaler.class) String types);
    /*</methods>*/
}
